IdFormatType enum
Enum class for ID format type. This is meant to allow devs to pick the ID number format that they want and is specific to their needs.
Usage:
IdFormatType.proper
IdFormatType.noSpace
Values
- proper → const IdFormatType
-
proper
This is the basic and most correct ID number format as seen on the identification cards issued by the government. Will also be used as the default for any usage within the package.
- noSpace → const IdFormatType
-
noSpace
This should be used when one wants an ID number without spaces e.g. 11223344K55
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IdFormatType> - A constant List of the values in this enum, in order of their declaration.