LocalSchools enum

Inheritance
Available extensions

Values

hit → const LocalSchools

Harare Institute of Technology

telone → const LocalSchools

Telone Centre for Learning

uz → const LocalSchools

University of Zimbabwe

msu → const LocalSchools

Midlands State University

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isStudent(String studentId) bool

Available on LocalSchools, provided by the StudentIDRegexExtension extension

isStudent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LocalSchools>
A constant List of the values in this enum, in order of their declaration.